@@ -1,11 +1,25 @@
 package BeerDB;
-use Maypole::Application qw/-Debug/;
+use Maypole::Application;
 use Class::DBI::Loader::Relationship;
 
-BEGIN {
-# This is the sample application. Change this to the path to your
+sub debug { $ENV{BEERDB_DEBUG} }
+# This is the sample application.  Change this to the path to your
 # database. (or use mysql or something)
-BeerDB->setup("dbi:SQLite:t/beerdb.db");
+use constant DBI_DRIVER => 'SQLite';
+use constant DATASOURCE => 't/beerdb.db';
+
+BEGIN {
+    my $dbi_driver = DBI_DRIVER;
+    if ($dbi_driver =~ /^SQLite/) {
+        die sprintf "SQLite datasource '%s' not found, correct the path or "
+            . "recreate the database by running Makefile.PL", DATASOURCE
+            unless -e DATASOURCE;
+        eval "require DBD::SQLite";
+        if ($@) {
+            eval "require DBD::SQLite2" and $dbi_driver = 'SQLite2';
+        }
+    }
+    BeerDB->setup(join ':', "dbi", $dbi_driver, DATASOURCE);
 }
 
 # Give it a name.
@@ -13,12 +27,12 @@ BeerDB->config->application_name('The Beer Database');
 
 # Change this to the root of the web space.
 BeerDB->config->uri_base("http://localhost/beerdb/");
-#BeerDB->config->{uri_base} = "http://neo.trinity-house.org.uk/beerdb/";
+#BeerDB->config->uri_base("http://neo.trinity-house.org.uk/beerdb/");
 
 BeerDB->config->rows_per_page(10);
 
 # Handpumps should not show up.
-BeerDB->config->{display_tables} = [qw[beer brewery pub style]];
+BeerDB->config->display_tables([qw[beer brewery pub style]]);
 BeerDB::Brewery->untaint_columns( printable => [qw/name notes url/] );
 BeerDB::Style->untaint_columns( printable => [qw/name notes/] );
 BeerDB::Beer->untaint_columns(
