@@ -1,6 +1,8 @@
 package Maypole::Model::CDBI::Plain;
 use base 'Maypole::Model::CDBI';
 
+Maypole::Config->mk_accessors(qw(table_to_class));
+
 sub setup_database {
     my ( $self, $config, $namespace, $classes ) = @_;
     $config->{classes}        = $classes;
@@ -26,13 +28,13 @@ Maypole::Model::CDBI::Plain - Class::DBI model without ::Loader
     use Foo::SomeTable;
     use Foo::Other::Table;
 
-    Foo->config->{model_class} = "Maypole::Model::CDBI::Plain";
+    Foo->config->model("Maypole::Model::CDBI::Plain");
     Foo->setup([qw/ Foo::SomeTable Foo::Other::Table /]);
 
 =head1 DESCRIPTION
 
 This module allows you to use Maypole with previously set-up
-C<Class::DBI> classes; simply call C<setup> with a list reference
+L<Class::DBI> classes; simply call C<setup> with a list reference
 of the classes you're going to use, and Maypole will work out the
 tables and set up the inheritance relationships as normal.
 
